summaryrefslogtreecommitdiffstats
path: root/src/plugins/platforms/wayland/gl_integration/readback_glx/qwaylandreadbackglxcontext.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/plugins/platforms/wayland/gl_integration/readback_glx/qwaylandreadbackglxcontext.cpp')
-rw-r--r--src/plugins/platforms/wayland/gl_integration/readback_glx/qwaylandreadbackglxcontext.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/plugins/platforms/wayland/gl_integration/readback_glx/qwaylandreadbackglxcontext.cpp b/src/plugins/platforms/wayland/gl_integration/readback_glx/qwaylandreadbackglxcontext.cpp
index dec2cdd428..850e7bb0ac 100644
--- a/src/plugins/platforms/wayland/gl_integration/readback_glx/qwaylandreadbackglxcontext.cpp
+++ b/src/plugins/platforms/wayland/gl_integration/readback_glx/qwaylandreadbackglxcontext.cpp
@@ -44,7 +44,7 @@
#include "qwaylandshmbackingstore.h"
#include "qwaylandreadbackglxwindow.h"
-#include <QtGui/QGuiGLContext>
+#include <QtGui/QOpenGLContext>
#include <QtCore/QDebug>
static inline void qgl_byteSwapImage(QImage &img, GLenum pixel_type)
@@ -70,7 +70,7 @@ static inline void qgl_byteSwapImage(QImage &img, GLenum pixel_type)
}
QWaylandReadbackGlxContext::QWaylandReadbackGlxContext(const QSurfaceFormat &format,
- QPlatformGLContext *share, Display *display, int screen)
+ QPlatformOpenGLContext *share, Display *display, int screen)
: m_display(display)
{
GLXFBConfig config = qglx_findConfig(display, screen, format, GLX_PIXMAP_BIT);
@@ -101,8 +101,8 @@ void QWaylandReadbackGlxContext::doneCurrent()
void QWaylandReadbackGlxContext::swapBuffers(QPlatformSurface *surface)
{
- // #### makeCurrent() directly on the platform context doesn't update QGuiGLContext::currentContext()
- if (QGuiGLContext::currentContext()->handle() != this)
+ // #### makeCurrent() directly on the platform context doesn't update QOpenGLContext::currentContext()
+ if (QOpenGLContext::currentContext()->handle() != this)
makeCurrent(surface);
QWaylandReadbackGlxWindow *w = static_cast<QWaylandReadbackGlxWindow *>(surface);